/** \file base_services.h"
 *  Initialize and release base services.
 */

// Copyright (C) 2014-2022 Sanford Rockowitz <rockowitz@minsoft.com>
// SPDX-License-Identifier: GPL-2.0-or-later

#ifndef BASE_SERVICES_H_
#define BASE_SERVICES_H_

void init_base_services();
void terminate_base_services();

#endif /* BASE_SERVICES_H_ */
